@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/)
 
 Usage::
 
@@ -35,6 +35,7 @@ from .type_defs import (
     CreateAgentResponseTypeDef,
     CreateLocationEfsResponseTypeDef,
     CreateLocationFsxLustreResponseTypeDef,
+    CreateLocationFsxOpenZfsResponseTypeDef,
     CreateLocationFsxWindowsResponseTypeDef,
     CreateLocationHdfsResponseTypeDef,
     CreateLocationNfsResponseTypeDef,
@@ -45,6 +46,7 @@ from .type_defs import (
     DescribeAgentResponseTypeDef,
     DescribeLocationEfsResponseTypeDef,
     DescribeLocationFsxLustreResponseTypeDef,
+    DescribeLocationFsxOpenZfsResponseTypeDef,
     DescribeLocationFsxWindowsResponseTypeDef,
     DescribeLocationHdfsResponseTypeDef,
     DescribeLocationNfsResponseTypeDef,
@@ -55,6 +57,7 @@ from .type_defs import (
     DescribeTaskResponseTypeDef,
     Ec2ConfigTypeDef,
     FilterRuleTypeDef,
+    FsxProtocolTypeDef,
     HdfsNameNodeTypeDef,
     ListAgentsResponseTypeDef,
     ListLocationsResponseTypeDef,
@@ -100,7 +103,7 @@ class Exceptions:
 class DataSyncClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/)
     """
 
     meta: ClientMeta
@@ -111,7 +114,7 @@ class DataSyncClient(BaseClient):
         DataSyncClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -119,7 +122,7 @@ class DataSyncClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#can_paginate)
         """
 
     def cancel_task_execution(self, *, TaskExecutionArn: str) -> Dict[str, Any]:
@@ -127,7 +130,7 @@ class DataSyncClient(BaseClient):
         Cancels execution of a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#cancel_task_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#cancel_task_execution)
         """
 
     def create_agent(
@@ -144,7 +147,7 @@ class DataSyncClient(BaseClient):
         Activates an DataSync agent that you have deployed on your host.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_agent)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_agent)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_agent)
         """
 
     def create_location_efs(
@@ -159,7 +162,7 @@ class DataSyncClient(BaseClient):
         Creates an endpoint for an Amazon EFS file system.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_efs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_efs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_efs)
         """
 
     def create_location_fsx_lustre(
@@ -174,7 +177,23 @@ class DataSyncClient(BaseClient):
         Creates an endpoint for an Amazon FSx for Lustre file system.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_lustre)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_lustre)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_lustre)
+        """
+
+    def create_location_fsx_open_zfs(
+        self,
+        *,
+        FsxFilesystemArn: str,
+        Protocol: "FsxProtocolTypeDef",
+        SecurityGroupArns: Sequence[str],
+        Subdirectory: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
+    ) -> CreateLocationFsxOpenZfsResponseTypeDef:
+        """
+        Creates an endpoint for an Amazon FSx for OpenZFS file system.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_open_zfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_open_zfs)
         """
 
     def create_location_fsx_windows(
@@ -192,7 +211,7 @@ class DataSyncClient(BaseClient):
         Creates an endpoint for an Amazon FSx for Windows File Server file system.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_windows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_windows)
         """
 
     def create_location_hdfs(
@@ -208,15 +227,15 @@ class DataSyncClient(BaseClient):
         QopConfiguration: "QopConfigurationTypeDef" = ...,
         SimpleUser: str = ...,
         KerberosPrincipal: str = ...,
-        KerberosKeytab: Union[bytes, IO[bytes], StreamingBody] = ...,
-        KerberosKrb5Conf: Union[bytes, IO[bytes], StreamingBody] = ...,
+        KerberosKeytab: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        KerberosKrb5Conf: Union[str, bytes, IO[Any], StreamingBody] = ...,
         Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationHdfsResponseTypeDef:
         """
         Creates an endpoint for a Hadoop Distributed File System (HDFS).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_hdfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_hdfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_hdfs)
         """
 
     def create_location_nfs(
@@ -233,7 +252,7 @@ class DataSyncClient(BaseClient):
         from or written to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_nfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_nfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_nfs)
         """
 
     def create_location_object_storage(
@@ -253,7 +272,7 @@ class DataSyncClient(BaseClient):
         Creates an endpoint for a self-managed object storage bucket.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_object_storage)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_object_storage)
         """
 
     def create_location_s3(
@@ -270,7 +289,7 @@ class DataSyncClient(BaseClient):
         Creates an endpoint for an Amazon S3 bucket.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_s3)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_s3)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_s3)
         """
 
     def create_location_smb(
@@ -290,7 +309,7 @@ class DataSyncClient(BaseClient):
         from or written to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_smb)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_smb)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_smb)
         """
 
     def create_task(
@@ -310,7 +329,7 @@ class DataSyncClient(BaseClient):
         Creates a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_task)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_task)
         """
 
     def delete_agent(self, *, AgentArn: str) -> Dict[str, Any]:
@@ -318,7 +337,7 @@ class DataSyncClient(BaseClient):
         Deletes an agent.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_agent)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_agent)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_agent)
         """
 
     def delete_location(self, *, LocationArn: str) -> Dict[str, Any]:
@@ -326,7 +345,7 @@ class DataSyncClient(BaseClient):
         Deletes the configuration of a location used by DataSync.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_location)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_location)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_location)
         """
 
     def delete_task(self, *, TaskArn: str) -> Dict[str, Any]:
@@ -334,7 +353,7 @@ class DataSyncClient(BaseClient):
         Deletes a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_task)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#delete_task)
         """
 
     def describe_agent(self, *, AgentArn: str) -> DescribeAgentResponseTypeDef:
@@ -343,7 +362,7 @@ class DataSyncClient(BaseClient):
         is, whether the agent is running or not) for an agent.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_agent)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_agent)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_agent)
         """
 
     def describe_location_efs(self, *, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
@@ -351,29 +370,40 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path information about an Amazon EFS location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_efs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_efs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_efs)
         """
 
     def describe_location_fsx_lustre(
         self, *, LocationArn: str
     ) -> DescribeLocationFsxLustreResponseTypeDef:
         """
-        Returns metadata, such as the path information about an Amazon FSx for Lustre
-        location.
+        Returns metadata about an Amazon FSx for Lustre location, such as information
+        about its path.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_lustre)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_lustre)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_lustre)
+        """
+
+    def describe_location_fsx_open_zfs(
+        self, *, LocationArn: str
+    ) -> DescribeLocationFsxOpenZfsResponseTypeDef:
+        """
+        Returns metadata about an Amazon FSx for OpenZFS location, such as information
+        about its path.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_open_zfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_open_zfs)
         """
 
     def describe_location_fsx_windows(
         self, *, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
         """
-        Returns metadata, such as the path information about an Amazon FSx for Windows
-        File Server location.
+        Returns metadata about an Amazon FSx for Windows File Server location, such as
+        information about its path.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_windows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_windows)
         """
 
     def describe_location_hdfs(self, *, LocationArn: str) -> DescribeLocationHdfsResponseTypeDef:
@@ -382,7 +412,7 @@ class DataSyncClient(BaseClient):
         Distributed File System (HDFS) location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_hdfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_hdfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_hdfs)
         """
 
     def describe_location_nfs(self, *, LocationArn: str) -> DescribeLocationNfsResponseTypeDef:
@@ -390,7 +420,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path information, about an NFS location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_nfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_nfs)
         """
 
     def describe_location_object_storage(
@@ -400,7 +430,7 @@ class DataSyncClient(BaseClient):
         Returns metadata about a self-managed object storage server location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_object_storage)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_object_storage)
         """
 
     def describe_location_s3(self, *, LocationArn: str) -> DescribeLocationS3ResponseTypeDef:
@@ -408,7 +438,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as bucket name, about an Amazon S3 bucket location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_s3)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_s3)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_s3)
         """
 
     def describe_location_smb(self, *, LocationArn: str) -> DescribeLocationSmbResponseTypeDef:
@@ -416,7 +446,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path and user information about an SMB location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_smb)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_smb)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_smb)
         """
 
     def describe_task(self, *, TaskArn: str) -> DescribeTaskResponseTypeDef:
@@ -424,7 +454,7 @@ class DataSyncClient(BaseClient):
         Returns metadata about a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_task)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_task)
         """
 
     def describe_task_execution(
@@ -434,7 +464,7 @@ class DataSyncClient(BaseClient):
         Returns detailed metadata about a task that is being executed.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_task_execution)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_task_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_task_execution)
         """
 
     def generate_presigned_url(
@@ -448,7 +478,7 @@ class DataSyncClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#generate_presigned_url)
         """
 
     def list_agents(
@@ -459,7 +489,7 @@ class DataSyncClient(BaseClient):
         Web Services Region specified in the request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_agents)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_agents)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_agents)
         """
 
     def list_locations(
@@ -473,7 +503,7 @@ class DataSyncClient(BaseClient):
         Returns a list of source and destination locations.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_locations)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_locations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_locations)
         """
 
     def list_tags_for_resource(
@@ -483,7 +513,7 @@ class DataSyncClient(BaseClient):
         Returns all the tags associated with a specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tags_for_resource)
         """
 
     def list_task_executions(
@@ -493,7 +523,7 @@ class DataSyncClient(BaseClient):
         Returns a list of executed tasks.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_task_executions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_task_executions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_task_executions)
         """
 
     def list_tasks(
@@ -507,7 +537,7 @@ class DataSyncClient(BaseClient):
         Returns a list of all the tasks.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tasks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tasks)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tasks)
         """
 
     def start_task_execution(
@@ -522,7 +552,7 @@ class DataSyncClient(BaseClient):
         Starts a specific invocation of a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.start_task_execution)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#start_task_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#start_task_execution)
         """
 
     def tag_resource(
@@ -532,7 +562,7 @@ class DataSyncClient(BaseClient):
         Applies a key-value pair to an Amazon Web Services resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, Keys: Sequence[str]) -> Dict[str, Any]:
@@ -540,7 +570,7 @@ class DataSyncClient(BaseClient):
         Removes a tag from an Amazon Web Services resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#untag_resource)
         """
 
     def update_agent(self, *, AgentArn: str, Name: str = ...) -> Dict[str, Any]:
@@ -548,7 +578,7 @@ class DataSyncClient(BaseClient):
         Updates the name of an agent.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_agent)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_agent)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_agent)
         """
 
     def update_location_hdfs(
@@ -564,8 +594,8 @@ class DataSyncClient(BaseClient):
         AuthenticationType: HdfsAuthenticationTypeType = ...,
         SimpleUser: str = ...,
         KerberosPrincipal: str = ...,
-        KerberosKeytab: Union[bytes, IO[bytes], StreamingBody] = ...,
-        KerberosKrb5Conf: Union[bytes, IO[bytes], StreamingBody] = ...,
+        KerberosKeytab: Union[str, bytes, IO[Any], StreamingBody] = ...,
+        KerberosKrb5Conf: Union[str, bytes, IO[Any], StreamingBody] = ...,
         AgentArns: Sequence[str] = ...
     ) -> Dict[str, Any]:
         """
@@ -573,7 +603,7 @@ class DataSyncClient(BaseClient):
         Distributed File System cluster.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_hdfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_hdfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_hdfs)
         """
 
     def update_location_nfs(
@@ -589,7 +619,7 @@ class DataSyncClient(BaseClient):
         System (NFS) access.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_nfs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_nfs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_nfs)
         """
 
     def update_location_object_storage(
@@ -608,7 +638,7 @@ class DataSyncClient(BaseClient):
         object storage server access.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_object_storage)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_object_storage)
         """
 
     def update_location_smb(
@@ -627,7 +657,7 @@ class DataSyncClient(BaseClient):
         Message Block (SMB) file system access.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_smb)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_smb)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_location_smb)
         """
 
     def update_task(
@@ -645,7 +675,7 @@ class DataSyncClient(BaseClient):
         Updates the metadata associated with a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_task)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_task)
         """
 
     def update_task_execution(
@@ -655,21 +685,21 @@ class DataSyncClient(BaseClient):
         Updates execution of a task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_task_execution)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_task_execution)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
         """
 
     @overload
@@ -678,7 +708,7 @@ class DataSyncClient(BaseClient):
     ) -> ListTagsForResourcePaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
         """
 
     @overload
@@ -687,12 +717,12 @@ class DataSyncClient(BaseClient):
     ) -> ListTaskExecutionsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#get_paginator)
         """
