@@ -38,6 +38,7 @@ __all__ = (
     "MtimeType",
     "NfsVersionType",
     "ObjectStorageServerProtocolType",
+    "ObjectTagsType",
     "OperatorType",
     "OverwriteModeType",
     "PhaseStatusType",
@@ -80,6 +81,7 @@ LogLevelType = Literal["BASIC", "OFF", "TRANSFER"]
 MtimeType = Literal["NONE", "PRESERVE"]
 NfsVersionType = Literal["AUTOMATIC", "NFS3", "NFS4_0", "NFS4_1"]
 ObjectStorageServerProtocolType = Literal["HTTP", "HTTPS"]
+ObjectTagsType = Literal["NONE", "PRESERVE"]
 OperatorType = Literal[
     "BeginsWith",
     "Contains",
@@ -155,6 +157,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -270,6 +273,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
