@@ -30,6 +30,7 @@ from .literals import (
     MtimeType,
     NfsVersionType,
     ObjectStorageServerProtocolType,
+    ObjectTagsType,
     OperatorType,
     OverwriteModeType,
     PhaseStatusType,
@@ -1090,6 +1091,7 @@ OptionsTypeDef = TypedDict(
         "LogLevel": LogLevelType,
         "TransferMode": TransferModeType,
         "SecurityDescriptorCopyFlags": SmbSecurityDescriptorCopyFlagsType,
+        "ObjectTags": ObjectTagsType,
     },
     total=False,
 )
